:mod:`art.estimators.certification.interval`
============================================
.. automodule:: art.estimators.certification.interval

PyTorchIBPClassifier
--------------------
.. autoclass:: PyTorchIBPClassifier
   :members:
   :special-members: __init__
   :no-inherited-members:

Interval Dense Layer
--------------------
.. autoclass:: PyTorchIntervalDense
   :members:
   :special-members: __init__
   :no-inherited-members:

Interval Convolution Layer
--------------------------
.. autoclass:: PyTorchIntervalConv2D
   :members:
   :special-members: __init__
   :no-inherited-members:

Interval Flatten Layer
----------------------
.. autoclass:: PyTorchIntervalFlatten
   :members:
   :special-members: __init__
   :no-inherited-members:

Interval ReLU
-------------
.. autoclass:: PyTorchIntervalReLU
   :members:
   :special-members: __init__
   :no-inherited-members:

Interval Bounds
---------------
.. autoclass:: PyTorchIntervalBounds
   :members:
   :special-members: __init__
   :no-inherited-members:
